@@ -274,7 +274,7 @@ class SettingsWidget(Gtk.Box):
         flag = Gio.SettingsBindFlags.GET
         if dep_key[0] == "!":
             dep_key = dep_key[1:]
-            flag |= Gio.Settings.BindFlags.INVERT_BOOLEAN
+            flag |= Gio.SettingsBindFlags.INVERT_BOOLEAN
 
         split = dep_key.split("/")
         dep_settings = Gio.Settings.new(split[0])
@@ -429,7 +429,7 @@ class FontButton(SettingsWidget):
     bind_prop = "font-name"
     bind_dir = Gio.SettingsBindFlags.DEFAULT
 
-    def __init__(self, label, size_group=None, dep_key=None, tooltip=""):
+    def __init__(self, label, level=(Gtk.FontChooserLevel.STYLE | Gtk.FontChooserLevel.SIZE), size_group=None, dep_key=None, tooltip=""):
         super(FontButton, self).__init__(dep_key=dep_key)
 
         self.label = SettingsLabel(label)
@@ -445,11 +445,32 @@ class FontButton(SettingsWidget):
         if size_group:
             self.add_to_size_group(size_group)
 
+        if not (level & Gtk.FontChooserLevel.STYLE):
+            # the level mechanism is broken in gtk - choosing a level that doesn't include styles (italics, bold, etc)
+            # results in a list that only has one variant per family, but in many cases the selected font is bold or
+            # italicized (but not consistenly), which is not only confusing, but kind of defeats the purpose. To work
+            # around that, we supply our own filter function that removes the variants correctly. If it ever gets fixed
+            # in gtk, this parsing function can be removed and the level argument added directly to the font button.
+            def filter_func(fam, face):
+                face_text = face.get_face_name().lower()
+                for keyword in ['bold', 'italic', 'oblique']:
+                    if keyword in face_text:
+                        return False
+
+                return True
+
+            self.content_widget.set_filter_func(filter_func)
+
+            # add the style level to avoid the issues above - it's because we're already filtering them out manually
+            level |= Gtk.FontChooserLevel.STYLE
+
+        self.content_widget.set_level(level)
+
 class Range(SettingsWidget):
     bind_prop = "value"
     bind_dir = Gio.SettingsBindFlags.GET | Gio.SettingsBindFlags.NO_SENSITIVITY
 
-    def __init__(self, label, min_label="", max_label="", mini=None, maxi=None, step=None, invert=False, log=False, show_value=True, dep_key=None, tooltip="", flipped=False, units=""):
+    def __init__(self, label, min_label="", max_label="", mini=None, maxi=None, step=None, invert=False, log=False, show_value=True, dep_key=None, tooltip="", flipped=False, units="", digits=1):
         super(Range, self).__init__(dep_key=dep_key)
 
         self.set_orientation(Gtk.Orientation.VERTICAL)
@@ -460,12 +481,11 @@ class Range(SettingsWidget):
         self.flipped = flipped
         self.timer = None
         self.value = 0
+        self.digits = digits
+        self.units = units
 
         hbox = Gtk.Box()
 
-        if units:
-            label += " ({})".format(units)
-
         self.label = Gtk.Label.new(label)
         self.label.set_halign(Gtk.Align.CENTER)
 
@@ -514,6 +534,12 @@ class Range(SettingsWidget):
         self.content_widget.set_draw_value(show_value and not self.flipped)
         self.bind_object = self.content_widget.get_adjustment()
 
+        if self.units != "":
+            def format_value(scale, value, data=None):
+                return "{0:0.{prec}f}{1}".format(value, self.units, prec=self.digits)
+
+            self.content_widget.connect("format-value", format_value)
+
         if invert:
             self.step *= -1 # Gtk.Scale.new_with_range want a positive value, but our custom scroll handler wants a negative value
 
@@ -527,8 +553,17 @@ class Range(SettingsWidget):
         self.content_widget.connect("scroll-event", self.on_scroll_event)
         self.content_widget.connect("value-changed", self.apply_later)
 
+        if (not log) and self.step % 1 == 0:
+            self.content_widget.connect("change-value", self.round_value_to_step)
+
         self.set_tooltip_text(tooltip)
 
+    def round_value_to_step(self, widget, scroll, value, data=None):
+        if value % self.step != 0:
+            widget.set_value(round(value / self.step) * self.step)
+            return True
+        return False
+
     def apply_later(self, *args):
         def apply(self):
             if self.log:
@@ -560,6 +595,7 @@ class Range(SettingsWidget):
 
     def set_rounding(self, digits):
         if not self.log:
+            self.digits = digits
             self.content_widget.set_round_digits(digits)
             self.content_widget.set_digits(digits)
 
